import { AppConfigure } from './AppConfigure';
import { IContainer, LoadType, MapSet, Factory, Token } from '@ts-ioc/core';
import { IApplicationBuilder, CustomRegister, AnyApplicationBuilder } from './IApplicationBuilder';
import { ModuleBuilder } from './ModuleBuilder';
/**
 * application builder.
 *
 * @export
 * @class Default ApplicationBuilder
 * @extends {ModuleBuilder}
 * @template T
 */
export declare class DefaultApplicationBuilder<T> extends ModuleBuilder<T> implements IApplicationBuilder<T> {
    baseURL?: string;
    protected globalConfig: Promise<AppConfigure>;
    protected customRegs: CustomRegister<T>[];
    protected providers: MapSet<Token<any>, any>;
    root: IContainer;
    constructor(baseURL?: string);
    static create(baseURL?: string): AnyApplicationBuilder;
    /**
     * use configuration.
     *
     * @param {(string | AppConfigure)} [config]
     * @returns {this} global config for this application.
     * @memberof Bootstrap
     */
    useConfiguration(config?: string | AppConfigure, container?: IContainer): this;
    /**
     * use module as global Depdences module.
     *
     * @param {...LoadType[]} modules
     * @returns {this}
     * @memberof PlatformServer
     */
    use(...modules: LoadType[]): this;
    /**
     * bind provider
     *
     * @template T
     * @param {Token<T>} provide
     * @param {Token<T> | Factory<T>} provider
     * @returns {this}
     * @memberof IContainer
     */
    provider(provide: Token<any>, provider: Token<any> | Factory<any>): this;
    registerConfgureDepds(container: IContainer, config: AppConfigure): Promise<AppConfigure>;
    protected mergeGlobalConfig(globalCfg: AppConfigure, moduleCfg: AppConfigure): AppConfigure;
    protected regDefaultContainer(): IContainer;
    /**
     * register ioc exts
     *
     * @protected
     * @param {IContainer} container
     * @param {AppConfigure} config
     * @returns {Promise<IContainer>}
     * @memberof ApplicationBuilder
     */
    protected registerExts(container: IContainer, config: AppConfigure): Promise<IContainer>;
    protected bindAppConfig(config: AppConfigure): AppConfigure;
    protected getDefaultConfig(): AppConfigure;
    static classAnnations: any;
}
